abacusai.feature_group_row_process_logs — AbacusAI documentation

# abacusai.feature_group_row_process_logs

## Classes

`FeatureGroupRowProcessLogs` | Logs for the feature group row process.

## Module Contents

class abacusai.feature_group_row_process_logs.FeatureGroupRowProcessLogs(client, logs=None, featureGroupId=None, deploymentId=None, primaryKeyValue=None, featureGroupRowProcessId=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Logs for the feature group row process.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - logs (str) – The logs for both stdout and stderr of the step

    - featureGroupId (str) – The ID of the feature group this row that was processed belongs to.

    - deploymentId (str) – The ID of the deployment that processed this row.

    - primaryKeyValue (str) – Value of the primary key for this row.

    - featureGroupRowProcessId (str) – The ID of the feature group row process.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict